@@ -30,13 +30,12 @@ def bhvRDM(bhv_data, sub_opt=1, method="correlation", abs=False):
         respectively.
     sub_opt: int 0 or 1. Default is 1.
         Return the results for each subject or after averaging.
-        If sub_opt=1, return the results of each subject.
-        If sub_opt=0, return the average result.
-    method : string 'correlation' or 'euclidean' or 'mahalanobis'. Default is 'correlation'.
+        If sub_opt=1, calculate the results of each subject (using the absolute distance).
+        If sub_opt=0, calculate the results averaging the trials and taking the subjects as the features.
+    method : string 'correlation' or 'euclidean'. Default is 'correlation'.
         The method to calculate the dissimilarities.
         If method='correlation', the dissimilarity is calculated by Pearson Correlation.
         If method='euclidean', the dissimilarity is calculated by Euclidean Distance, the results will be normalized.
-        If method='mahalanobis', the dissimilarity is calculated by Mahalanobis Distance, the results will be normalized.
     abs : boolean True or False. Default is True.
         Calculate the absolute value of Pearson r or not. Only works when method='correlation'.
 
@@ -51,7 +50,7 @@ def bhvRDM(bhv_data, sub_opt=1, method="correlation", abs=False):
     -----
     This function can also be used to calculate the RDM for computational simulation data.
         For example, users can extract the activations for a certain layer i which includes Nn nodes in a deep
-        convolutional neural network (DCNN) corresponding to Ni images. Thus, the input could be a [Ni, 1, Nn] matrix, M.
+        convolutional neural network (DCNN) corresponding to Ni images. Thus, the input could be a [Ni, 1, Nn] matrix M.
         Using "bhvRDM(M, sub_opt=0)", users can obtain the DCNN RDM for layer i.
     """
 
@@ -148,7 +147,7 @@ def bhvRDM(bhv_data, sub_opt=1, method="correlation", abs=False):
     # calculate the values in RDM
     for i in range(cons):
         for j in range(cons):
-            if method is 'correlation':
+            if method == 'correlation':
                 # calculate the Pearson Coefficient
                 r = pearsonr(data[i], data[j])[0]
                 # calculate the dissimilarity
@@ -156,13 +155,9 @@ def bhvRDM(bhv_data, sub_opt=1, method="correlation", abs=False):
                     rdm[i, j] = limtozero(1 - np.abs(r))
                 else:
                     rdm[i, j] = limtozero(1 - r)
-            elif method is 'euclidean':
+            elif method == 'euclidean':
                 rdm[i, j] = np.linalg.norm(data[i]-data[j])
-            elif method is 'mahalanobis':
-                X = np.transpose(np.vstack((data[i], data[j])), (1, 0))
-                X = np.dot(X, np.linalg.inv(np.cov(X, rowvar=False)))
-                rdm[i, j] = np.linalg.norm(X[:, 0]-X[:, 1])
-    if method is 'euclidean' or method is 'mahalanobis':
+    if method == 'euclidean':
         max = np.max(rdm)
         min = np.min(rdm)
         rdm = (rdm-min)/(max-min)
@@ -205,11 +200,10 @@ def eegRDM(EEG_data, sub_opt=1, chl_opt=0, time_opt=0, time_win=5, time_step=5,
     time_step : int. Default is 5.
         The time step size for each time of calculating.
         Only when time_opt=1, time_step works.
-    method : string 'correlation' or 'euclidean' or 'mahalanobis'. Default is 'correlation'.
+    method : string 'correlation' or 'euclidean'. Default is 'correlation'.
         The method to calculate the dissimilarities.
         If method='correlation', the dissimilarity is calculated by Pearson Correlation.
         If method='euclidean', the dissimilarity is calculated by Euclidean Distance, the results will be normalized.
-        If method='mahalanobis', the dissimilarity is calculated by Mahalanobis Distance, the results will be normalized.
     abs : boolean True or False. Default is True.
         Calculate the absolute value of Pearson r or not.
 
@@ -295,13 +289,13 @@ def eegRDM(EEG_data, sub_opt=1, chl_opt=0, time_opt=0, time_win=5, time_step=5,
                                         rdms[i, j, k, l, m] = limtozero(1 - np.abs(r))
                                     else:
                                         rdms[i, j, k, l, m] = limtozero(1 - r)
-                                elif method is 'euclidean':
+                                elif method == 'euclidean':
                                     rdms[i, j, k, l, m] = np.linalg.norm(data[i, j, k, l] - data[i, j, k, m])
-                                elif method is 'mahalanobis':
+                                """elif method == 'mahalanobis':
                                     X = np.transpose(np.vstack((data[i, j, k, l], data[i, j, k, m])), (1, 0))
                                     X = np.dot(X, np.linalg.inv(np.cov(X, rowvar=False)))
-                                    rdms[i, j, k, l, m] = np.linalg.norm(X[:, 0] - X[:, 1])
-                        if method is 'euclidean' or method is 'mahalanobis':
+                                    rdms[i, j, k, l, m] = np.linalg.norm(X[:, 0] - X[:, 1])"""
+                        if method == 'euclidean':
                             max = np.max(rdms[i, j, k])
                             min = np.min(rdms[i, j, k])
                             rdms[i, j, k] = (rdms[i, j, k] - min) / (max - min)
@@ -341,21 +335,17 @@ def eegRDM(EEG_data, sub_opt=1, chl_opt=0, time_opt=0, time_win=5, time_step=5,
 
                 for l in range(cons):
                     for m in range(cons):
-                        if method is 'correlation':
+                        if method == 'correlation':
                             # calculate the Pearson Coefficient
                             r = pearsonr(data[i, k, l], data[i, k, m])[0]
                             # calculate the dissimilarity
-                            if abs == True:
+                            if abs is True:
                                 rdms[i, k, l, m] = limtozero(1 - np.abs(r))
                             else:
                                 rdms[i, k, l, m] = limtozero(1 - r)
-                        elif method is 'euclidean':
+                        elif method == 'euclidean':
                             rdms[i, k, l, m] = np.linalg.norm(data[i, k, l] - data[i, k, m])
-                        elif method is 'mahalanobis':
-                            X = np.transpose(np.vstack((data[i, k, l], data[i, k, m])), (1, 0))
-                            X = np.dot(X, np.linalg.inv(np.cov(X, rowvar=False)))
-                            rdms[i, k, l, m] = np.linalg.norm(X[:, 0] - X[:, 1])
-                if method is 'euclidean' or method is 'mahalanobis':
+                if method == 'euclidean':
                     max = np.max(rdms[i, k])
                     min = np.min(rdms[i, k])
                     rdms[i, k] = (rdms[i, k] - min) / (max - min)
@@ -401,7 +391,7 @@ def eegRDM(EEG_data, sub_opt=1, chl_opt=0, time_opt=0, time_win=5, time_step=5,
 
                 for k in range(cons):
                     for l in range(cons):
-                        if method is 'correlation':
+                        if method == 'correlation':
                             # calculate the Pearson Coefficient
                             r = pearsonr(data[k, i, j], data[l, i, j])[0]
                             # calculate the dissimilarity
@@ -409,13 +399,9 @@ def eegRDM(EEG_data, sub_opt=1, chl_opt=0, time_opt=0, time_win=5, time_step=5,
                                 rdms[i, j, k, l] = limtozero(1 - np.abs(r))
                             else:
                                 rdms[i, j, k, l] = limtozero(1 - r)
-                        elif method is 'euclidean':
+                        elif method == 'euclidean':
                             rdms[i, j, k, l] = np.linalg.norm(data[k, i, j] - data[k, i, j])
-                        elif method is 'mahalanobis':
-                            X = np.transpose(np.vstack((data[k, i, j], data[l, i, j])), (1, 0))
-                            X = np.dot(X, np.linalg.inv(np.cov(X, rowvar=False)))
-                            rdms[i, j, k, l] = np.linalg.norm(X[:, 0] - X[:, 1])
-                if method is 'euclidean' or method is 'mahalanobis':
+                if method == 'euclidean':
                     max = np.max(rdms[i, j])
                     min = np.min(rdms[i, j])
                     rdms[i, j] = (rdms[i, j] - min) / (max - min)
@@ -459,21 +445,21 @@ def eegRDM(EEG_data, sub_opt=1, chl_opt=0, time_opt=0, time_win=5, time_step=5,
     for i in range(subs):
         for j in range(cons):
             for k in range(cons):
-                if method is 'correlation':
+                if method == 'correlation':
                     # calculate the Pearson Coefficient
                     r = pearsonr(data[j, i], data[k, i])[0]
                     # calculate the dissimilarity
-                    if abs is True:
+                    if abs == True:
                         rdms[i, j, k] = limtozero(1 - np.abs(r))
                     else:
                         rdms[i, j, k] = limtozero(1 - r)
-                elif method is 'euclidean':
+                elif method == 'euclidean':
                     rdms[i, j, k] = np.linalg.norm(data[j, i] - data[k, i])
-                elif method is 'mahalanobis':
+                """elif method == 'mahalanobis':
                     X = np.transpose(np.vstack((data[j, i], data[k, i])), (1, 0))
                     X = np.dot(X, np.linalg.inv(np.cov(X, rowvar=False)))
-                    rdms[i, j, k] = np.linalg.norm(X[:, 0] - X[:, 1])
-        if method is 'euclidean' or method is 'mahalanobis':
+                    rdms[i, j, k] = np.linalg.norm(X[:, 0] - X[:, 1])"""
+        if method == 'euclidean':
             max = np.max(rdms[i])
             min = np.min(rdms[i])
             rdms[i] = (rdms[i] - min) / (max - min)
@@ -610,11 +596,10 @@ def fmriRDM(fmri_data, ksize=[3, 3, 3], strides=[1, 1, 1], sub_opt=1, method="co
         Return the subject-result or average-result.
         If sub_opt=0, return the average result.
         If sub_opt=1, return the results of each subject.
-    method : string 'correlation' or 'euclidean' or 'mahalanobis'. Default is 'correlation'.
+    method : string 'correlation' or 'euclidean'. Default is 'correlation'.
         The method to calculate the dissimilarities.
         If method='correlation', the dissimilarity is calculated by Pearson Correlation.
         If method='euclidean', the dissimilarity is calculated by Euclidean Distance, the results will be normalized.
-        If method='mahalanobis', the dissimilarity is calculated by Mahalanobis Distance, the results will be normalized.
     abs : boolean True or False. Default is True.
         Calculate the absolute value of Pearson r or not.
 
@@ -669,7 +654,7 @@ def fmriRDM(fmri_data, ksize=[3, 3, 3], strides=[1, 1, 1], sub_opt=1, method="co
                         for k2 in range(ky):
                             for k3 in range(kz):
                                 for j in range(subs):
-                                    data[x, y, z, i, index, j] = fmri_data[i, j, x+k1, y+k2, z+k3]
+                                    data[x, y, z, i, index, j] = fmri_data[i, j, x*sx+k1, y*sy+k2, z*sz+k3]
 
                                 index = index + 1
 
@@ -700,7 +685,7 @@ def fmriRDM(fmri_data, ksize=[3, 3, 3], strides=[1, 1, 1], sub_opt=1, method="co
                             # no NaN
                             if (np.isnan(data[:, x, y, z, i]).any() == False) and \
                                     (np.isnan(data[:, x, y, z, j]).any() == False):
-                                if method is 'correlation':
+                                if method == 'correlation':
                                     # calculate the Pearson Coefficient
                                     r = pearsonr(data[sub, x, y, z, i], data[sub, x, y, z, j])[0]
                                     # calculate the dissimilarity
@@ -708,13 +693,14 @@ def fmriRDM(fmri_data, ksize=[3, 3, 3], strides=[1, 1, 1], sub_opt=1, method="co
                                         subrdms[sub, x, y, z, i, j] = limtozero(1 - np.abs(r))
                                     else:
                                         subrdms[sub, x, y, z, i, j] = limtozero(1 - r)
-                                elif method is 'euclidean':
-                                    subrdms[sub, x, y, z, i, j] = np.linalg.norm(data[sub, x, y, z, i] - data[sub, x, y, z, j])
-                                elif method is 'mahalanobis':
+                                elif method == 'euclidean':
+                                    subrdms[sub, x, y, z, i, j] = np.linalg.norm(data[sub, x, y, z, i] -
+                                                                                 data[sub, x, y, z, j])
+                                """elif method == 'mahalanobis':
                                     X = np.transpose(np.vstack((data[sub, x, y, z, i], data[sub, x, y, z, j])), (1, 0))
                                     X = np.dot(X, np.linalg.inv(np.cov(X, rowvar=False)))
-                                    subrdms[sub, x, y, z, i, j] = np.linalg.norm(X[:, 0] - X[:, 1])
-                    if method is 'euclidean' or method is 'mahalanobis':
+                                    subrdms[sub, x, y, z, i, j] = np.linalg.norm(X[:, 0] - X[:, 1])"""
+                    if method == 'euclidean':
                         max = np.max(subrdms[sub, x, y, z])
                         min = np.min(subrdms[sub, x, y, z])
                         subrdms[sub, x, y, z] = (subrdms[sub, x, y, z] - min) / (max - min)
@@ -753,11 +739,10 @@ def fmriRDM_roi(fmri_data, mask_data, sub_opt=1, method="correlation", abs=False
         Return the subject-result or average-result.
         If sub_opt=0, return the average result.
         If sub_opt=1, return the results of each subject.
-    method : string 'correlation' or 'euclidean' or 'mahalanobis'. Default is 'correlation'.
+    method : string 'correlation' or 'euclidean'. Default is 'correlation'.
         The method to calculate the dissimilarities.
         If method='correlation', the dissimilarity is calculated by Pearson Correlation.
         If method='euclidean', the dissimilarity is calculated by Euclidean Distance, the results will be normalized.
-        If method='mahalanobis', the dissimilarity is calculated by Mahalanobis Distance, the results will be normalized.
     abs : boolean True or False. Default is True.
         Calculate the absolute value of Pearson r or not.
 
@@ -828,7 +813,7 @@ def fmriRDM_roi(fmri_data, mask_data, sub_opt=1, method="correlation", abs=False
             for j in range(ncons):
 
                 if (np.isnan(data[:, i]).any() == False) and (np.isnan(data[:, j]).any() == False):
-                    if method is 'correlation':
+                    if method == 'correlation':
                         # calculate the Pearson Coefficient
                         r = pearsonr(data[sub, i], data[sub, j])[0]
                         # calculate the dissimilarity
@@ -836,13 +821,13 @@ def fmriRDM_roi(fmri_data, mask_data, sub_opt=1, method="correlation", abs=False
                             subrdms[sub, i, j] = limtozero(1 - np.abs(r))
                         else:
                             subrdms[sub, i, j] = limtozero(1 - r)
-                    elif method is 'euclidean':
+                    elif method == 'euclidean':
                         subrdms[sub, i, j] = np.linalg.norm(data[sub, i] - data[sub, j])
-                    elif method is 'mahalanobis':
+                    """elif method == 'mahalanobis':
                         X = np.transpose(np.vstack((data[sub, i], data[sub, j])), (1, 0))
                         X = np.dot(X, np.linalg.inv(np.cov(X, rowvar=False)))
-                        subrdms[sub, i, j] = np.linalg.norm(X[:, 0] - X[:, 1])
-        if method is 'euclidean' or method is 'mahalanobis':
+                        subrdms[sub, i, j] = np.linalg.norm(X[:, 0] - X[:, 1])"""
+        if method == 'euclidean':
             max = np.max(subrdms[sub])
             min = np.min(subrdms[sub])
             subrdms[sub] = (subrdms[sub] - min) / (max - min)
