@@ -5,6 +5,7 @@
 __author__ = 'Zitong Lu'
 
 import numpy as np
+import copy
 import matplotlib.pyplot as plt
 from scipy.interpolate import interp1d
 from scipy import signal
@@ -53,6 +54,8 @@ def plot_rdm(rdm, percentile=False, rescale=False, lim=[0, 1], conditions=None,
     # get the number of conditions
     cons = rdm.shape[0]
 
+    crdm = copy.deepcopy(rdm)
+
     # if cons=2, the RDM cannot be plotted.
     if cons == 2:
         print("The shape of RDM cannot be 2*2. Here NeuroRA cannot plot this RDM.")
@@ -60,7 +63,7 @@ def plot_rdm(rdm, percentile=False, rescale=False, lim=[0, 1], conditions=None,
         return None
 
     # determine if it's a square
-    a, b = np.shape(rdm)
+    a, b = np.shape(crdm)
     if a != b:
         return None
 
@@ -69,7 +72,7 @@ def plot_rdm(rdm, percentile=False, rescale=False, lim=[0, 1], conditions=None,
         v = np.zeros([cons * cons, 2], dtype=np.float)
         for i in range(cons):
             for j in range(cons):
-                v[i * cons + j, 0] = rdm[i, j]
+                v[i * cons + j, 0] = crdm[i, j]
 
         index = np.argsort(v[:, 0])
         m = 0
@@ -83,12 +86,12 @@ def plot_rdm(rdm, percentile=False, rescale=False, lim=[0, 1], conditions=None,
 
         for i in range(cons):
             for j in range(cons):
-                rdm[i, j] = v[i * cons + j, 0]
+                crdm[i, j] = v[i * cons + j, 0]
 
         if cmap == None:
-            plt.imshow(rdm, extent=(0, 1, 0, 1), cmap=plt.cm.jet, clim=(0, 100))
+            plt.imshow(crdm, extent=(0, 1, 0, 1), cmap=plt.cm.jet, clim=(0, 100))
         else:
-            plt.imshow(rdm, extent=(0, 1, 0, 1), cmap=cmap, clim=(0, 100))
+            plt.imshow(crdm, extent=(0, 1, 0, 1), cmap=cmap, clim=(0, 100))
 
     # rescale the RDM
     elif rescale == True:
@@ -112,15 +115,15 @@ def plot_rdm(rdm, percentile=False, rescale=False, lim=[0, 1], conditions=None,
 
                     # not on the diagnal
                     if i != j:
-                        rdm[i, j] = float((rdm[i, j] - minvalue) / (maxvalue - minvalue))
+                        crdm[i, j] = float((crdm[i, j] - minvalue) / (maxvalue - minvalue))
 
         # plot the RDM
         min = lim[0]
         max = lim[1]
         if cmap == None:
-            plt.imshow(rdm, extent=(0, 1, 0, 1), cmap=plt.cm.jet, clim=(min, max))
+            plt.imshow(crdm, extent=(0, 1, 0, 1), cmap=plt.cm.jet, clim=(min, max))
         else:
-            plt.imshow(rdm, extent=(0, 1, 0, 1), cmap=cmap, clim=(min, max))
+            plt.imshow(crdm, extent=(0, 1, 0, 1), cmap=cmap, clim=(min, max))
 
     else:
 
@@ -128,9 +131,9 @@ def plot_rdm(rdm, percentile=False, rescale=False, lim=[0, 1], conditions=None,
         min = lim[0]
         max = lim[1]
         if cmap == None:
-            plt.imshow(rdm, extent=(0, 1, 0, 1), cmap=plt.cm.jet, clim=(min, max))
+            plt.imshow(crdm, extent=(0, 1, 0, 1), cmap=plt.cm.jet, clim=(min, max))
         else:
-            plt.imshow(rdm, extent=(0, 1, 0, 1), cmap=cmap, clim=(min, max))
+            plt.imshow(crdm, extent=(0, 1, 0, 1), cmap=cmap, clim=(min, max))
 
     # plt.axis("off")
     cb = plt.colorbar()
@@ -197,8 +200,10 @@ def plot_rdm_withvalue(rdm, lim=[0, 1], value_fontsize=10, conditions=None, con_
 
         return None
 
+    crdm = copy.deepcopy(rdm)
+
     # determine if it's a square
-    a, b = np.shape(rdm)
+    a, b = np.shape(crdm)
     if a != b:
         return None
 
@@ -206,9 +211,9 @@ def plot_rdm_withvalue(rdm, lim=[0, 1], value_fontsize=10, conditions=None, con_
     min = lim[0]
     max = lim[1]
     if cmap == None:
-        plt.imshow(rdm, extent=(0, 1, 0, 1), cmap=plt.cm.Greens, clim=(min, max))
+        plt.imshow(crdm, extent=(0, 1, 0, 1), cmap=plt.cm.Greens, clim=(min, max))
     else:
-        plt.imshow(rdm, extent=(0, 1, 0, 1), cmap=cmap, clim=(min, max))
+        plt.imshow(crdm, extent=(0, 1, 0, 1), cmap=cmap, clim=(min, max))
 
     # plt.axis("off")
     cb = plt.colorbar()
@@ -344,7 +349,7 @@ def plot_corrs_by_time(corrs, labels=None, time_unit=[0, 0.1]):
 
 def plot_tbytsim_withstats(similarities, start_time=0, end_time=1, time_interval=0.01, smooth=True, p=0.05, cbpt=True,
                            clusterp=0.05, stats_time=[0, 1], color='r', xlim=[0, 1], ylim=[-0.1, 0.8],
-                           figsize=[6.4, 3.6], x0=0, fontsize=16, avgshow=False):
+                           figsize=[6.4, 3.6], x0=0, ticksize=12, fontsize=16, markersize=2, avgshow=False):
 
     """
     Plot the time-by-time Similarities with statistical results
@@ -383,8 +388,12 @@ def plot_tbytsim_withstats(similarities, start_time=0, end_time=1, time_interval
         The size of the figure.
     x0 : float. Default is 0.
         The Y-axis is at x=x0.
+    ticksize : int or float. Default is 12.
+        The size of the ticks.
     fontsize : int or float. Default is 16.
         The fontsize of the labels.
+    markersize : int or float. Default is 2.
+        The size of significant marker.
     avgshow : boolen True or False. Default is False.
         Show the averaging decoding accuracies or not.
     """
@@ -401,7 +410,9 @@ def plot_tbytsim_withstats(similarities, start_time=0, end_time=1, time_interval
     if n == 3:
         similarities = similarities[:, :, 0]
 
-    nsubs, nts = np.shape(similarities)
+    csimilarities = copy.deepcopy(similarities)
+
+    nsubs, nts = np.shape(csimilarities)
     tstep = float(Decimal((end_time - start_time) / nts).quantize(Decimal(str(time_interval))))
 
     if tstep != time_interval:
@@ -423,27 +434,27 @@ def plot_tbytsim_withstats(similarities, start_time=0, end_time=1, time_interval
             for t in range(nts):
 
                 if t<=1:
-                    similarities[sub, t] = np.average(similarities[sub, :t+3])
+                    csimilarities[sub, t] = np.average(csimilarities[sub, :t+3])
                 if t>1 and t<(nts-2):
-                    similarities[sub, t] = np.average(similarities[sub, t-2:t+3])
+                    csimilarities[sub, t] = np.average(csimilarities[sub, t-2:t+3])
                 if t>=(nts-2):
-                    similarities[sub, t] = np.average(similarities[sub, t-2:])
+                    csimilarities[sub, t] = np.average(csimilarities[sub, t-2:])
 
-    avg = np.average(similarities, axis=0)
+    avg = np.average(csimilarities, axis=0)
     err = np.zeros([nts], dtype=np.float)
 
     for t in range(nts):
-        err[t] = np.std(similarities[:, t], ddof=1)/np.sqrt(nsubs)
+        err[t] = np.std(csimilarities[:, t], ddof=1)/np.sqrt(nsubs)
 
     if cbpt == True:
-        ps_stats = clusterbased_permutation_1d_1samp_1sided(similarities[:, stats_time1:stats_time2], level=0,
+        ps_stats = clusterbased_permutation_1d_1samp_1sided(csimilarities[:, stats_time1:stats_time2], level=0,
                                                             p_threshold=p, clusterp_threshold=clusterp)
         ps = np.zeros([nts])
         ps[stats_time1:stats_time2] = ps_stats
     else:
         ps = np.zeros([nts])
         for t in range(nts):
-            ps[t] = ttest_1samp(similarities[:, t], 0, alternative="greater")[1]
+            ps[t] = ttest_1samp(csimilarities[:, t], 0, alternative="greater")[1]
             if ps[t] < p:
                 ps[t] = 1
             else:
@@ -452,7 +463,7 @@ def plot_tbytsim_withstats(similarities, start_time=0, end_time=1, time_interval
     for t in range(nts):
         if ps[t] == 1:
             plt.plot(t*tstep+start_time+0.5*tstep, (ymaxlim-yminlim)*0.95+yminlim, 's',
-                     color=color, alpha=0.8, markersize=2)
+                     color=color, alpha=0.8, markersize=markersize)
             xi = [t*tstep+start_time, t*tstep+tstep+start_time]
             ymin = [0]
             ymax = [avg[t]-err[t]]
@@ -474,7 +485,7 @@ def plot_tbytsim_withstats(similarities, start_time=0, end_time=1, time_interval
     plt.fill_between(x, avg + err, avg - err, facecolor=color, alpha=0.8)
     plt.ylim(yminlim, ymaxlim)
     plt.xlim(xlim[0], xlim[1])
-    plt.tick_params(labelsize=12)
+    plt.tick_params(labelsize=ticksize)
     plt.xlabel("Time (s)", fontsize=fontsize)
     plt.ylabel("Representational Similarity", fontsize=fontsize)
     plt.show()
@@ -486,7 +497,7 @@ def plot_tbytsim_withstats(similarities, start_time=0, end_time=1, time_interval
 
 def plot_tbyt_decoding_acc(acc, start_time=0, end_time=1, time_interval=0.01, chance=0.5, p=0.05, cbpt=True,
                            clusterp=0.05, stats_time=[0, 1], color='r', xlim=[0, 1], ylim=[0.4, 0.8],
-                           figsize=[6.4, 3.6], x0=0, fontsize=16, avgshow=False):
+                           figsize=[6.4, 3.6], x0=0, ticksize=12, fontsize=16, markersize=2, avgshow=False):
 
     """
     Plot the time-by-time decoding accuracies
@@ -523,8 +534,12 @@ def plot_tbyt_decoding_acc(acc, start_time=0, end_time=1, time_interval=0.01, ch
         The size of the figure.
     x0 : float. Default is 0.
         The Y-axis is at x=x0.
+    ticksize : int or float. Default is 12.
+        The size of the ticks.
     fontsize : int or float. Default is 16.
         The fontsize of the labels.
+    markersize : int or float. Default is 2.
+        The size of significant marker.
     avgshow : boolen True or False. Default is False.
         Show the averaging decoding accuracies or not.
     """
@@ -579,7 +594,7 @@ def plot_tbyt_decoding_acc(acc, start_time=0, end_time=1, time_interval=0.01, ch
     for t in range(nts):
         if ps[t] == 1:
             plt.plot(t*tstep+start_time+0.5*tstep, (ymaxlim-yminlim)*0.95+yminlim, 's', color=color, alpha=0.8,
-                     markersize=2)
+                     markersize=markersize)
             xi = [t*tstep+start_time, t*tstep+tstep+start_time]
             ymin = [chance]
             ymax = [avg[t] - err[t]]
@@ -600,7 +615,7 @@ def plot_tbyt_decoding_acc(acc, start_time=0, end_time=1, time_interval=0.01, ch
     plt.fill_between(x, avg+err, avg-err, facecolor=color, alpha=0.8)
     plt.ylim(yminlim, ymaxlim)
     plt.xlim(xlim[0], xlim[1])
-    plt.tick_params(labelsize=12)
+    plt.tick_params(labelsize=ticksize)
     plt.xlabel("Time (s)", fontsize=fontsize)
     plt.ylabel("Decoding Accuracy", fontsize=fontsize)
     plt.show()
@@ -610,7 +625,7 @@ def plot_tbyt_decoding_acc(acc, start_time=0, end_time=1, time_interval=0.01, ch
 
 def plot_tbyt_diff_decoding_acc(acc1, acc2, start_time=0, end_time=1, time_interval=0.01, chance=0.5, p=0.05, cbpt=True,
                                 clusterp=0.05, stats_time=[0, 1], color1='r', color2='b', xlim=[0, 1], ylim=[0.4, 0.8],
-                                figsize=[6.4, 3.6], x0=0, fontsize=16, avgshow=False):
+                                figsize=[6.4, 3.6], x0=0, ticksize=12, fontsize=16, markersize=2, avgshow=False):
 
     """
     Plot the differences of time-by-time decoding accuracies between two conditions
@@ -653,8 +668,12 @@ def plot_tbyt_diff_decoding_acc(acc1, acc2, start_time=0, end_time=1, time_inter
         The size of the figure.
     x0 : float. Default is 0.
         The Y-axis is at x=x0.
+    ticksize : int or float. Default is 12.
+        The size of the ticks.
     fontsize : int or float. Default is 16.
         The fontsize of the labels.
+    markersize : int or float. Default is 2.
+        The size of significant marker.
     avgshow : boolen True or False. Default is False.
         Show the averaging decoding accuracies or not.
     """
@@ -696,11 +715,11 @@ def plot_tbyt_diff_decoding_acc(acc1, acc2, start_time=0, end_time=1, time_inter
 
     if cbpt == True:
 
-        ps1_stats = clusterbased_permutation_2d_1samp_1sided(acc1[:, stats_time1:stats_time2], level=chance,
+        ps1_stats = clusterbased_permutation_1d_1samp_1sided(acc1[:, stats_time1:stats_time2], level=chance,
                                                              p_threshold=p, clusterp_threshold=clusterp, iter=1000)
         ps1 = np.zeros([nts])
         ps1[stats_time1:stats_time2] = ps1_stats
-        ps2_stats = clusterbased_permutation_2d_1samp_1sided(acc2[:, stats_time1:stats_time2], level=chance,
+        ps2_stats = clusterbased_permutation_1d_1samp_1sided(acc2[:, stats_time1:stats_time2], level=chance,
                                                              p_threshold=p, clusterp_threshold=clusterp, iter=1000)
         ps2 = np.zeros([nts])
         ps2[stats_time1:stats_time2] = ps2_stats
@@ -736,10 +755,10 @@ def plot_tbyt_diff_decoding_acc(acc1, acc2, start_time=0, end_time=1, time_inter
     for t in range(nts):
         if ps1[t] == 1:
             plt.plot(t*tstep+start_time+0.5*tstep, (ymaxlim-yminlim)*0.95+yminlim, 's', color=color1, alpha=0.8,
-                     markersize=2)
+                     markersize=markersize)
         if ps2[t] == 1:
             plt.plot(t*tstep+start_time+0.5*tstep, (ymaxlim-yminlim)*0.91+yminlim, 's', color=color2, alpha=0.8,
-                     markersize=2)
+                     markersize=markersize)
         if ps[t] == 1:
             xi = [t*tstep+start_time, t*tstep+tstep+start_time]
             ymin = [avg2[t] + err2[t]]
@@ -768,7 +787,7 @@ def plot_tbyt_diff_decoding_acc(acc1, acc2, start_time=0, end_time=1, time_inter
     plt.fill_between(x, avg2+err2, avg2-err2, facecolor=color2, alpha=0.8)
     plt.ylim(yminlim, ymaxlim)
     plt.xlim(xlim[0], xlim[1])
-    plt.tick_params(labelsize=12)
+    plt.tick_params(labelsize=ticksize)
     plt.xlabel("Time (s)", fontsize=fontsize)
     plt.ylabel("Decoding Accuracy", fontsize=fontsize)
     plt.show()
@@ -779,7 +798,7 @@ def plot_tbyt_diff_decoding_acc(acc1, acc2, start_time=0, end_time=1, time_inter
 def plot_ct_decoding_acc(acc, start_timex=0, end_timex=1, start_timey=0, end_timey=1, time_intervalx=0.01,
                          time_intervaly=0.01, chance=0.5, p=0.05, cbpt=True, clusterp=0.05, stats_timex=[0, 1],
                          stats_timey=[0, 1], xlim=[0, 1], ylim=[0, 1], clim=[0.4, 0.8], figsize=[6.4, 4.8],
-                         cmap="viridis", fontsize=16):
+                         cmap="viridis", ticksize=12, fontsize=16):
 
     """
     Plot the cross-temporal decoding accuracies
@@ -824,6 +843,8 @@ def plot_ct_decoding_acc(acc, start_timex=0, end_timex=1, start_timey=0, end_tim
         The size of the figure.
     cmap : matplotlib colormap or None. Default is None.
         The colormap for the figure.
+    ticksize : int or float. Default is 12.
+        The size of the ticks.
     fontsize : int or float. Default is 16.
         The fontsize of the labels.
     """
@@ -899,12 +920,12 @@ def plot_ct_decoding_acc(acc, start_timex=0, end_timex=1, start_timey=0, end_tim
     plt.imshow(avg, extent=(start_timex, end_timex, start_timey, end_timey), cmap=cmap, origin="lower",
                clim=(cminlim, cmaxlim))
     cb = plt.colorbar()
-    cb.ax.tick_params(labelsize=12)
-    font = {'size': 15}
+    cb.ax.tick_params(labelsize=ticksize)
+    font = {'size': ticksize+2}
     cb.set_label("Decoding Accuracy", fontdict=font)
     plt.xlim(xlim[0], xlim[1])
     plt.ylim(ylim[0], ylim[1])
-    plt.tick_params(labelsize=12)
+    plt.tick_params(labelsize=ticksize)
     plt.xlabel("Training Time (s)", fontsize=fontsize)
     plt.ylabel("Test Time (s)", fontsize=fontsize)
     plt.show()
@@ -913,8 +934,9 @@ def plot_ct_decoding_acc(acc, start_timex=0, end_timex=1, start_timey=0, end_tim
 ' a function for plotting the differences of cross-temporal decoding accuracies between two conditions '
 
 def plot_ct_diff_decoding_acc(acc1, acc2, start_timex=0, end_timex=1, start_timey=0, end_timey=1, time_intervalx=0.01,
-                         time_intervaly=0.01, p=0.05, cbpt=True, clusterp=0.05, stats_timex=[0, 1], stats_timey=[0, 1],
-                         xlim=[0, 1], ylim=[0, 1], clim=[0.4, 0.8], figsize=[6.4, 4.8], cmap="viridis", fontsize=16):
+                              time_intervaly=0.01, p=0.05, cbpt=True, clusterp=0.05, stats_timex=[0, 1],
+                              stats_timey=[0, 1], xlim=[0, 1], ylim=[0, 1], clim=[0.4, 0.8], figsize=[6.4, 4.8],
+                              cmap="viridis", ticksize=12, fontsize=16):
 
     """
     Plot the differences of cross-temporal decoding accuracies between two conditions
@@ -963,6 +985,8 @@ def plot_ct_diff_decoding_acc(acc1, acc2, start_timex=0, end_timex=1, start_time
         The size of the figure.
     cmap : matplotlib colormap or None. Default is None.
         The colormap for the figure.
+    ticksize : int or float. Default is 12.
+        The size of the ticks.
     fontsize : int or float. Default is 16.
         The fontsize of the labels.
     """
@@ -1040,12 +1064,12 @@ def plot_ct_diff_decoding_acc(acc1, acc2, start_timex=0, end_timex=1, start_time
     plt.imshow(avg, extent=(start_timex, end_timex, start_timey, end_timey), cmap=cmap, origin="lower",
                clim=(cminlim, cmaxlim))
     cb = plt.colorbar()
-    cb.ax.tick_params(labelsize=12)
-    font = {'size': 15}
+    cb.ax.tick_params(labelsize=ticksize)
+    font = {'size': ticksize+2}
     cb.set_label("Differences of Decoding Accuracies", fontdict=font)
     plt.xlim(xlim[0], xlim[1])
     plt.ylim(ylim[0], ylim[1])
-    plt.tick_params(labelsize=12)
+    plt.tick_params(labelsize=ticksize)
     plt.xlabel("Training Time (s)", fontsize=fontsize)
     plt.ylabel("Test Time (s)", fontsize=fontsize)
     plt.show()
@@ -1149,27 +1173,29 @@ def plot_corrs_hotmap(corrs, chllabels=None, time_unit=[0, 0.1], lim=[0, 1], smo
         elif len(corrs.shape) == 2:
             rlts = corrs
 
-    # get min of lims & max of lims
-    limmin = lim[0]
-    limmax = lim[1]
-
-    if cmap == None:
-        plt.imshow(rlts, extent=(start_t, end_t, 0, nchls*0.16), clim=(limmin, limmax), origin='lower', cmap='inferno')
-    else:
-        plt.imshow(rlts, extent=(start_t, end_t, 0, nchls * 0.16), clim=(limmin, limmax), origin='lower', cmap=cmap)
-
     fig = plt.gcf()
     size = fig.get_size_inches()
 
     if figsize == None:
-        size_x = ts*tstep*(size[0]-2)+2
-        size_y = nchls*0.2*(size[1]-1.5)+1.5
+        size_x = ts * tstep * (size[0] - 2) + 2
+        size_y = nchls * 0.2 * (size[1] - 1.5) + 1.5
     else:
         size_x = figsize[0]
         size_y = figsize[1]
 
     fig.set_size_inches(size_x, size_y)
 
+    delta = (size_y * 3) / (size_x * 4)
+
+    # get min of lims & max of lims
+    limmin = lim[0]
+    limmax = lim[1]
+
+    if cmap == None:
+        plt.imshow(rlts, extent=(start_t, end_t, 0, nchls*0.16*delta), clim=(limmin, limmax), origin='lower', cmap='inferno')
+    else:
+        plt.imshow(rlts, extent=(start_t, end_t, 0, nchls * 0.16*delta), clim=(limmin, limmax), origin='lower', cmap=cmap)
+
     cb = plt.colorbar()
     cb.ax.tick_params(labelsize=16)
     font = {'size': 18}
@@ -1178,7 +1204,7 @@ def plot_corrs_hotmap(corrs, chllabels=None, time_unit=[0, 0.1], lim=[0, 1], smo
     xi = []
 
     for i in range(nchls):
-        xi.append(0.16*i + 0.08)
+        xi.append(0.16*delta*i + 0.08*delta)
 
     yi = chllabels
 
@@ -1195,7 +1221,7 @@ def plot_corrs_hotmap(corrs, chllabels=None, time_unit=[0, 0.1], lim=[0, 1], smo
 ' a function for plotting the hotmap of correlations coefficients for channels/regions by time sequence with the significant outline '
 
 def plot_corrs_hotmap_withstats(corrs, chllabels=None, time_unit=[0, 0.1], lim=[0, 1], p=0.05, cbpt=False,
-                                clusterp=0.05, stats_time=[0, 1], smooth=False, figsize=None, cmap=None):
+                                clusterp=0.05, stats_time=[0, 1], smooth=False, ticksize=18, figsize=None, cmap=None):
 
     """
     plot the hotmap of correlation coefficients for channels/regions by time sequence with the significant outline
@@ -1225,6 +1251,8 @@ def plot_corrs_hotmap_withstats(corrs, chllabels=None, time_unit=[0, 0.1], lim=[
         The time period for statistical analysis.
     smooth : bool True or False. Default is False.
         Smooth the results or not.
+    ticksize : int or float. Default is 18.
+        The size of the ticks.
     figsize : array or list, [size_X, size_Y]
         The size of the figure.
         If figsize=None, the size of the figure will be ajusted automatically.
@@ -1289,6 +1317,20 @@ def plot_corrs_hotmap_withstats(corrs, chllabels=None, time_unit=[0, 0.1], lim=[
         for chl in range(nchls):
             rlts[:, chl] = smooth_1d(rlts[:, chl])
 
+    fig = plt.gcf()
+    size = fig.get_size_inches()
+
+    if figsize == None:
+        size_x = nts * tstep * (size[0] - 2) + 2
+        size_y = nchls * 0.2 * (size[1] - 1.5) + 1.5
+    else:
+        size_x = figsize[0]
+        size_y = figsize[1]
+
+    fig.set_size_inches(size_x, size_y)
+
+    delta = (size_y * 3) / (size_x * 4)
+
     avg = np.average(rlts, axis=0)
 
     ps = np.zeros([nchls, nts])
@@ -1316,7 +1358,7 @@ def plot_corrs_hotmap_withstats(corrs, chllabels=None, time_unit=[0, 0.1], lim=[
     newps[1:nchls + 1, 1:nts + 1] = ps
 
     x = np.linspace(start_time - 0.5 * tstep, end_time + 0.5 * tstep, nts + 2)
-    y = np.linspace(-0.08, 0.16 * nchls + 0.08, nchls + 2)
+    y = np.linspace(-0.08*delta, 0.16*delta * nchls + 0.08*delta, nchls + 2)
     X, Y = np.meshgrid(x, y)
     plt.contour(X, Y, newps, [0.5], linewidths=2, linestyles="dashed")
     plt.contour(X, Y, newps, [-0.5], linewidths=2, linestyles="dashed")
@@ -1326,36 +1368,24 @@ def plot_corrs_hotmap_withstats(corrs, chllabels=None, time_unit=[0, 0.1], lim=[
     limmax = lim[1]
 
     if cmap == None:
-        plt.imshow(avg, extent=(start_time, end_time, 0, nchls*0.16), clim=(limmin, limmax), origin='lower', cmap='inferno')
+        plt.imshow(avg, extent=(start_time, end_time, 0, nchls*delta*0.16), clim=(limmin, limmax), origin='lower', cmap='inferno')
     else:
-        plt.imshow(avg, extent=(start_time, end_time, 0, nchls * 0.16), clim=(limmin, limmax), origin='lower', cmap=cmap)
-
-    fig = plt.gcf()
-    size = fig.get_size_inches()
-
-    if figsize == None:
-        size_x = nts*tstep*(size[0]-2)+2
-        size_y = nchls*0.2*(size[1]-1.5)+1.5
-    else:
-        size_x = figsize[0]
-        size_y = figsize[1]
-
-    fig.set_size_inches(size_x, size_y)
+        plt.imshow(avg, extent=(start_time, end_time, 0, nchls*delta * 0.16), clim=(limmin, limmax), origin='lower', cmap=cmap)
 
     cb = plt.colorbar()
-    cb.ax.tick_params(labelsize=16)
-    font = {'size': 18}
+    cb.ax.tick_params(labelsize=ticksize-2)
+    font = {'size': ticksize}
     cb.set_label("Similarity", fontdict=font)
 
     xi = []
 
     for i in range(nchls):
-        xi.append(0.16*i + 0.08)
+        xi.append(0.16*delta*i + 0.08*delta)
 
     yi = chllabels
 
-    plt.tick_params(labelsize=18)
-    plt.yticks(xi, yi, fontsize=18)
+    plt.tick_params(labelsize=ticksize)
+    plt.yticks(xi, yi, fontsize=ticksize)
     plt.ylabel("Channel", fontsize=20)
     plt.xlabel("Time (s)", fontsize=20)
 
@@ -1457,27 +1487,29 @@ def plot_nps_hotmap(similarities, chllabels=None, time_unit=[0, 0.1], lim=[0, 1]
     if smooth == False:
         rlts = similarities
 
-    # get min of lims & max of lims
-    limmin = lim[0]
-    limmax = lim[1]
-
-    if cmap == None:
-        plt.imshow(rlts, extent=(start_t, end_t, 0, nchls*0.16), clim=(limmin, limmax), origin='lower')
-    else:
-        plt.imshow(rlts, extent=(start_t, end_t, 0, nchls*0.16), clim=(limmin, limmax), origin='lower', cmap=cmap)
-
     fig = plt.gcf()
     size = fig.get_size_inches()
 
     if figsize == None:
-        size_x = ts*tstep*(size[0]-2)+2
-        size_y = nchls*0.2*(size[1]-1.5)+1.5
+        size_x = ts * tstep * (size[0] - 2) + 2
+        size_y = nchls * 0.2 * (size[1] - 1.5) + 1.5
     else:
         size_x = figsize[0]
         size_y = figsize[1]
 
     fig.set_size_inches(size_x, size_y)
 
+    delta = (size_y * 3) / (size_x * 4)
+
+    # get min of lims & max of lims
+    limmin = lim[0]
+    limmax = lim[1]
+
+    if cmap == None:
+        plt.imshow(rlts, extent=(start_t, end_t, 0, nchls*delta*0.16), clim=(limmin, limmax), origin='lower')
+    else:
+        plt.imshow(rlts, extent=(start_t, end_t, 0, nchls*delta*0.16), clim=(limmin, limmax), origin='lower', cmap=cmap)
+
     cb = plt.colorbar()
     cb.ax.tick_params(labelsize=16)
     font = {'size': 18}
@@ -1486,7 +1518,7 @@ def plot_nps_hotmap(similarities, chllabels=None, time_unit=[0, 0.1], lim=[0, 1]
     xi = []
 
     for i in range(nchls):
-        xi.append(0.16*i + 0.08)
+        xi.append(0.16*delta*i + 0.08*delta)
 
     yi = chllabels
 
@@ -1503,7 +1535,7 @@ def plot_nps_hotmap(similarities, chllabels=None, time_unit=[0, 0.1], lim=[0, 1]
 ' a function for plotting the hotmap of statistical results for channels/regions by time sequence '
 
 def plot_t_hotmap_withstats(results, chllabels=None, time_unit=[0, 0.1], lim=[-7, 7], p=0.05, cbpt=False,
-                            clusterp=0.05, stats_time=[0, 1], smooth=False, figsize=None, cmap=None):
+                            clusterp=0.05, stats_time=[0, 1], smooth=False, ticksize=18, figsize=None, cmap=None):
 
     """
     plot the hotmap of statistical results for channels/regions by time sequence
@@ -1533,6 +1565,8 @@ def plot_t_hotmap_withstats(results, chllabels=None, time_unit=[0, 0.1], lim=[-7
         The time period for statistical analysis.
     smooth : bool True or False. Default is False.
         Smooth the results or not.
+    ticksize : int or float. Default is 18.
+        The size of the ticks.
     figsize : array or list, [size_X, size_Y]
         The size of the figure.
         If figsize=None, the size of the figure will be ajusted automatically.
@@ -1596,6 +1630,20 @@ def plot_t_hotmap_withstats(results, chllabels=None, time_unit=[0, 0.1], lim=[-7
         for chl in range(nchls):
             rlts[:, chl] = smooth_1d(rlts[:, chl])
 
+    fig = plt.gcf()
+    size = fig.get_size_inches()
+
+    if figsize == None:
+        size_x = nts * tstep * (size[0] - 2) + 2
+        size_y = nchls * 0.2 * (size[1] - 1.5) + 1.5
+    else:
+        size_x = figsize[0]
+        size_y = figsize[1]
+
+    fig.set_size_inches(size_x, size_y)
+
+    delta = (size_y * 3) / (size_x * 4)
+
     ts = ttest_1samp(rlts, 0, axis=0)[:, :, 0]
 
     ps = np.zeros([nchls, nts])
@@ -1622,7 +1670,7 @@ def plot_t_hotmap_withstats(results, chllabels=None, time_unit=[0, 0.1], lim=[-7
     newps[1:nchls + 1, 1:nts + 1] = ps
 
     x = np.linspace(start_time - 0.5 * tstep, end_time + 0.5 * tstep, nts + 2)
-    y = np.linspace(-0.08, 0.16 * nchls + 0.08, nchls + 2)
+    y = np.linspace(-0.08*delta, 0.16*delta * nchls + 0.08*delta, nchls + 2)
     X, Y = np.meshgrid(x, y)
     plt.contour(X, Y, newps, [0.5], linewidths=2, linestyles="dashed")
     plt.contour(X, Y, newps, [-0.5], linewidths=2, linestyles="dashed")
@@ -1632,38 +1680,26 @@ def plot_t_hotmap_withstats(results, chllabels=None, time_unit=[0, 0.1], lim=[-7
     limmax = lim[1]
 
     if cmap == None:
-        plt.imshow(ts, extent=(start_time, end_time, 0, nchls * 0.16), clim=(limmin, limmax), origin='lower',
+        plt.imshow(ts, extent=(start_time, end_time, 0, nchls * 0.16*delta), clim=(limmin, limmax), origin='lower',
                    cmap='bwr')
     else:
-        plt.imshow(ts, extent=(start_time, end_time, 0, nchls * 0.16), clim=(limmin, limmax), origin='lower',
+        plt.imshow(ts, extent=(start_time, end_time, 0, nchls * 0.16*delta), clim=(limmin, limmax), origin='lower',
                    cmap=cmap)
 
-    fig = plt.gcf()
-    size = fig.get_size_inches()
-
-    if figsize == None:
-        size_x = nts * tstep * (size[0] - 2) + 2
-        size_y = nchls * 0.2 * (size[1] - 1.5) + 1.5
-    else:
-        size_x = figsize[0]
-        size_y = figsize[1]
-
-    fig.set_size_inches(size_x, size_y)
-
     cb = plt.colorbar()
-    cb.ax.tick_params(labelsize=16)
-    font = {'size': 18}
+    cb.ax.tick_params(labelsize=ticksize-2)
+    font = {'size': ticksize}
     cb.set_label("t", fontdict=font)
 
     xi = []
 
     for i in range(nchls):
-        xi.append(0.16 * i + 0.08)
+        xi.append(0.16*delta * i + 0.08*delta)
 
     yi = chllabels
 
-    plt.tick_params(labelsize=18)
-    plt.yticks(xi, yi, fontsize=18)
+    plt.tick_params(labelsize=ticksize)
+    plt.yticks(xi, yi, fontsize=ticksize)
     plt.ylabel("Channel", fontsize=20)
     plt.xlabel("Time (s)", fontsize=20)
 
@@ -1956,4 +1992,7 @@ def plot_brainrsa_rlts(img, threshold=None, slice=[6, 6, 6], background=None, ty
 
             plot_brainrsa_surface(img, threshold=threshold, type=type)
 
-    return 0
\ No newline at end of file
+    return 0
+
+rdm = np.random.rand(7, 7)
+plot_rdm(rdm, percentile=True)
\ No newline at end of file
